``ncol`` keyword argument to ``legend`` renamed to ``ncols``
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

The ``ncol`` keyword argument to `~.Axes.legend` for controlling the number of
columns is renamed to ``ncols`` for consistency with the ``ncols`` and
``nrows`` keywords of `~.Figure.subplots` and `~.GridSpec`.
``ncol`` is still supported though.
